using Plots

"""
    Create plots comparing the Julia & PySDM vertical profiles
"""
function plot_comparison(KM; sdm_case = "dry", name = "dry")
    sdm_data = load_sdm_data(sdm_case)
    path = joinpath(@__DIR__, "output")
    mkpath(path)

    fig_name = string(name, "_init_profile.png")

    p1 = Plots.plot(KM.q_vap, KM.z_centers, label = "KM", xlabel = "q_vap [g/kg]", ylabel = "z [m]")
    Plots.plot!(p1, sdm_data.qv_sdm, sdm_data.z_sdm, label = "SDM")

    p2 = Plots.plot(KM.ρ, KM.z_centers, label = "KM ρ_tot", xlabel = "ρ [kg/m3]", ylabel = "z [m]")
    Plots.plot!(p2, sdm_data.rho_sdm, sdm_data.z_sdm, label = "SDM ρ")

    p3 = Plots.plot(KM.θ_dry, KM.z_centers, label = "KM", xlabel = "θ_dry [K]", ylabel = "z [m]")
    Plots.plot!(p3, sdm_data.thetad_sdm, sdm_data.z_sdm, label = "SDM")

    p4 = Plots.plot(KM.T, KM.z_centers, label = "KM", xlabel = "T [K]", ylabel = "z [m]")
    Plots.plot!(p4, sdm_data.T_sdm, sdm_data.z_sdm, label = "SDM")

    p5 = Plots.plot(KM.p ./ 100, KM.z_centers, label = "KM", xlabel = "p [hPa]", ylabel = "z [m]")
    Plots.plot!(p5, sdm_data.P_sdm ./ 100, sdm_data.z_sdm, label = "SDM")

    p6 = Plots.plot(KM.q_liq, KM.z_centers, label = "KM", xlabel = "q_liq [g/kg]", ylabel = "z [m]")
    Plots.plot!(p6, sdm_data.ql_sdm, sdm_data.z_sdm, label = "SDM")

    p = Plots.plot(
        p1,
        p2,
        p3,
        p4,
        p5,
        p6,
        size = (1200.0, 750.0),
        bottom_margin = 40.0 * Plots.PlotMeasures.px,
        left_margin = 80.0 * Plots.PlotMeasures.px,
    )
    Plots.png(p, joinpath(path, fig_name))
end

"""
    Load the statically-stored PySDM profiles
"""
function load_sdm_data(case = "dry")

#! format: off
    if case=="dry"
            z_sdm = [  10.,   30.,   50.,   70.,   90.,  110.,  130.,  150.,  170.,
            190.,  210.,  230.,  250.,  270.,  290.,  310.,  330.,  350.,
            370.,  390.,  410.,  430.,  450.,  470.,  490.,  510.,  530.,
            550.,  570.,  590.,  610.,  630.,  650.,  670.,  690.,  710.,
            730.,  750.,  770.,  790.,  810.,  830.,  850.,  870.,  890.,
            910.,  930.,  950.,  970.,  990., 1010., 1030., 1050., 1070.,
           1090., 1110., 1130., 1150., 1170., 1190., 1210., 1230., 1250.,
           1270., 1290., 1310., 1330., 1350., 1370., 1390., 1410., 1430.,
           1450., 1470., 1490., 1510., 1530., 1550., 1570., 1590., 1610.,
           1630., 1650., 1670., 1690., 1710., 1730., 1750., 1770., 1790.,
           1810., 1830., 1850., 1870., 1890., 1910., 1930., 1950., 1970.,
           1990., 2010., 2030., 2050., 2070., 2090., 2110., 2130., 2150.,
           2170., 2190., 2210., 2230., 2250., 2270., 2290., 2310., 2330.,
           2350., 2370., 2390., 2410., 2430., 2450., 2470., 2490., 2510.,
           2530., 2550., 2570., 2590., 2610., 2630., 2650., 2670., 2690.,
           2710., 2730., 2750., 2770., 2790., 2810., 2830., 2850., 2870.,
           2890., 2910., 2930., 2950., 2970., 2990.]

            ql_sdm = [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
            0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
            0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
            0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
            0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
            0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
            0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
            0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
            0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.]

            qv_sdm = [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
            0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
            0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
            0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
            0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
            0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
            0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
            0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
            0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.]

            rhod_sdm = [1.17449888, 1.17257814, 1.1706593 , 1.16874234, 1.16682726,
            1.16491407, 1.16300277, 1.16109334, 1.1591858 , 1.15728015,
            1.15537637, 1.15347448, 1.15157447, 1.14967633, 1.14778008,
            1.1458857 , 1.14399321, 1.14210259, 1.14021384, 1.13832698,
            1.13644198, 1.13455887, 1.13267763, 1.13079826, 1.12892076,
            1.12704514, 1.12517139, 1.12329951, 1.1214295 , 1.11956136,
            1.11769509, 1.11583069, 1.11396816, 1.11210749, 1.11024869,
            1.10839176, 1.10653669, 1.10468361, 1.10283329, 1.10098585,
            1.09914128, 1.09729958, 1.09546074, 1.09362477, 1.09179164,
            1.08996137, 1.08813394, 1.08630935, 1.0844876 , 1.08266868,
            1.08085259, 1.07903932, 1.07722886, 1.07542123, 1.07361639,
            1.07181437, 1.07001514, 1.06821871, 1.06642507, 1.06463422,
            1.06284614, 1.06106085, 1.05927833, 1.05749857, 1.05572158,
            1.05394735, 1.05217588, 1.05040715, 1.04864117, 1.04687794,
            1.04511744, 1.04335967, 1.04160463, 1.03985232, 1.03810273,
            1.03635585, 1.03461168, 1.03287022, 1.03113146, 1.02939541,
            1.02766204, 1.02593137, 1.02420337, 1.02247807, 1.02075543,
            1.01903547, 1.01731818, 1.01560355, 1.01389158, 1.01218227,
            1.01047561, 1.00877159, 1.00707022, 1.00537149, 1.00367539,
            1.00198192, 1.00029107, 0.99860285, 0.99691725, 0.99523426,
            0.99355387, 0.9918761 , 0.99020092, 0.98852834, 0.98685835,
            0.98519096, 0.98352614, 0.98186391, 0.98020425, 0.97854716,
            0.97689265, 0.97524069, 0.9735913 , 0.97194446, 0.97030017,
            0.96865843, 0.96701924, 0.96538258, 0.96374846, 0.96211687,
            0.96048781, 0.95886127, 0.95723726, 0.95561575, 0.95399676,
            0.95238028, 0.9507663 , 0.94915482, 0.94754583, 0.94593934,
            0.94433533, 0.94273381, 0.94113477, 0.9395382 , 0.93794411,
            0.93635248, 0.93476332, 0.93317662, 0.93159237, 0.93001058,
            0.92843123, 0.92685434, 0.92527988, 0.92370786, 0.92213827,
            0.92057111, 0.91900638, 0.91744407, 0.91588418, 0.9143267 ]

            thetad_sdm = [297.9       , 297.9       , 297.9       , 297.9       ,
            297.9       , 297.9       , 297.9       , 297.9       ,
            297.9       , 297.9       , 297.9       , 297.9       ,
            297.9       , 297.9       , 297.9       , 297.9       ,
            297.9       , 297.9       , 297.9       , 297.9       ,
            297.9       , 297.9       , 297.9       , 297.9       ,
            297.9       , 297.9       , 297.9       , 297.9       ,
            297.9       , 297.9       , 297.9       , 297.9       ,
            297.9       , 297.9       , 297.9       , 297.9       ,
            297.9       , 297.95857143, 298.07571429, 298.19285714,
            298.31      , 298.42714286, 298.54428571, 298.66142857,
            298.77857143, 298.89571429, 299.01285714, 299.13      ,
            299.24714286, 299.36428571, 299.48142857, 299.59857143,
            299.71571429, 299.83285714, 299.95      , 300.06714286,
            300.18428571, 300.30142857, 300.41857143, 300.53571429,
            300.65285714, 300.77      , 300.88714286, 301.00428571,
            301.12142857, 301.23857143, 301.35571429, 301.47285714,
            301.59      , 301.70714286, 301.82428571, 301.94142857,
            302.05857143, 302.17571429, 302.29285714, 302.41      ,
            302.52714286, 302.64428571, 302.76142857, 302.87857143,
            302.99571429, 303.11285714, 303.23      , 303.34714286,
            303.46428571, 303.58142857, 303.69857143, 303.81571429,
            303.93285714, 304.05      , 304.16714286, 304.28428571,
            304.40142857, 304.51857143, 304.63571429, 304.75285714,
            304.87      , 304.98714286, 305.10428571, 305.22142857,
            305.33857143, 305.45571429, 305.57285714, 305.69      ,
            305.80714286, 305.92428571, 306.04142857, 306.15857143,
            306.27571429, 306.39285714, 306.51      , 306.62714286,
            306.74428571, 306.86142857, 306.97857143, 307.09571429,
            307.21285714, 307.33      , 307.44714286, 307.56428571,
            307.68142857, 307.79857143, 307.91571429, 308.03285714,
            308.15      , 308.26714286, 308.38428571, 308.50142857,
            308.61857143, 308.73571429, 308.85285714, 308.97      ,
            309.08714286, 309.20428571, 309.32142857, 309.43857143,
            309.55571429, 309.67285714, 309.79      , 309.90714286,
            310.02428571, 310.14142857, 310.25857143, 310.37571429,
            310.49285714, 310.61      , 310.72714286, 310.84428571,
            310.96142857, 311.07857143]

            T_sdm = [298.39644745, 298.20129024, 298.00613302, 297.81097581,
            297.6158186 , 297.42066138, 297.22550417, 297.03034695,
            296.83518974, 296.64003253, 296.44487531, 296.2497181 ,
            296.05456089, 295.85940367, 295.66424646, 295.46908924,
            295.27393203, 295.07877482, 294.8836176 , 294.68846039,
            294.49330317, 294.29814596, 294.10298875, 293.90783153,
            293.71267432, 293.5175171 , 293.32235989, 293.12720268,
            292.93204546, 292.73688825, 292.54173103, 292.34657382,
            292.15141661, 291.95625939, 291.76110218, 291.56594496,
            291.37078775, 291.25578016, 291.22086126, 291.18586017,
            291.15077691, 291.1156115 , 291.08036396, 291.0450343 ,
            291.00962256, 290.97412875, 290.93855288, 290.90289498,
            290.86715507, 290.83133316, 290.79542927, 290.75944343,
            290.72337565, 290.68722595, 290.65099436, 290.61468088,
            290.57828555, 290.54180837, 290.50524938, 290.46860858,
            290.43188599, 290.39508164, 290.35819555, 290.32122773,
            290.2841782 , 290.24704699, 290.2098341 , 290.17253957,
            290.1351634 , 290.09770562, 290.06016625, 290.02254531,
            289.98484281, 289.94705878, 289.90919323, 289.87124618,
            289.83321765, 289.79510766, 289.75691623, 289.71864338,
            289.68028912, 289.64185348, 289.60333648, 289.56473813,
            289.52605845, 289.48729746, 289.44845518, 289.40953163,
            289.37052683, 289.33144079, 289.29227354, 289.25302509,
            289.21369547, 289.17428469, 289.13479276, 289.09521972,
            289.05556557, 289.01583034, 288.97601405, 288.93611671,
            288.89613834, 288.85607896, 288.81593859, 288.77571725,
            288.73541496, 288.69503173, 288.65456759, 288.61402255,
            288.57339663, 288.53268985, 288.49190223, 288.45103379,
            288.41008454, 288.36905451, 288.32794371, 288.28675215,
            288.24547987, 288.20412688, 288.1626932 , 288.12117883,
            288.07958382, 288.03790816, 287.99615189, 287.95431501,
            287.91239755, 287.87039953, 287.82832095, 287.78616186,
            287.74392225, 287.70160215, 287.65920158, 287.61672055,
            287.57415909, 287.53151721, 287.48879493, 287.44599227,
            287.40310925, 287.36014588, 287.31710219, 287.27397819,
            287.23077389, 287.18748933, 287.14412451, 287.10067946,
            287.05715419, 287.01354872, 286.96986307, 286.92609726,
            286.8822513 , 286.83832521]

            P_sdm = [100584.77388511, 100354.60428728, 100124.81122361,  99895.39432411,
            99666.35321891,  99437.68753826,  99209.39691253,  98981.48097221,
            98753.93934793,  98526.7716704 ,  98299.9775705 ,  98073.5566792 ,
            97847.50862761,  97621.83304694,  97396.52956855,  97171.5978239 ,
            96947.03744458,  96722.84806231,  96499.02930891,  96275.58081635,
            96052.5022167 ,  95829.79314216,  95607.45322506,  95385.48209784,
            95163.87939306,  94942.64474342,  94721.77778174,  94501.27814093,
            94281.14545407,  94061.37935433,  93841.97947502,  93622.94544955,
            93404.27691148,  93185.97349447,  92968.03483233,  92750.46055896,
            92533.2503084 ,  92341.82529607,  92176.10243684,  92010.63118419,
            91845.41119964,  91680.44214512,  91515.72368306,  91351.25547632,
            91187.03718823,  91023.06848257,  90859.34902358,  90695.87847596,
            90532.65650487,  90369.68277589,  90206.95695511,  90044.47870901,
            89882.24770458,  89720.26360921,  89558.52609078,  89397.0348176 ,
            89235.78945844,  89074.78968249,  88914.03515943,  88753.52555936,
            88593.26055283,  88433.23981084,  88273.46300483,  88113.92980668,
            87954.63988873,  87795.59292375,  87636.78858495,  87478.22654598,
            87319.90648095,  87161.82806439,  87003.99097127,  86846.394877  ,
            86689.03945745,  86531.92438888,  86375.04934804,  86218.41401207,
            86062.01805858,  85905.86116558,  85749.94301156,  85594.26327539,
            85438.8216364 ,  85283.61777437,  85128.65136947,  84973.92210232,
            84819.42965399,  84665.17370593,  84511.15394007,  84357.37003873,
            84203.82168467,  84050.50856109,  83897.43035159,  83744.58674022,
            83591.97741142,  83439.6020501 ,  83287.46034154,  83135.55197149,
            82983.87662609,  82832.43399192,  82681.22375597,  82530.24560564,
            82379.49922877,  82228.98431361,  82078.70054882,  81928.64762348,
            81778.8252271 ,  81629.23304958,  81479.87078126,  81330.73811287,
            81181.83473558,  81033.16034095,  80884.71462096,  80736.49726801,
            80588.50797491,  80440.74643487,  80293.2123415 ,  80145.90538885,
            79998.82527136,  79851.97168387,  79705.34432165,  79558.94288035,
            79412.76705605,  79266.81654522,  79121.09104473,  78975.59025188,
            78830.31386434,  78685.26158021,  78540.43309797,  78395.82811653,
            78251.44633517,  78107.28745358,  77963.35117186,  77819.63719051,
            77676.14521041,  77532.87493284,  77389.8260595 ,  77246.99829247,
            77104.39133422,  76962.00488763,  76819.83865596,  76677.89234288,
            76536.16565244,  76394.65828909,  76253.36995767,  76112.30036341,
            75971.44921194,  75830.81620925,  75690.40106177,  75550.20347628,
            75410.22315997,  75270.45982039]

    elseif case=="wet"
        z_sdm = [  10.,   30.,   50.,   70.,   90.,  110.,  130.,  150.,  170.,
        190.,  210.,  230.,  250.,  270.,  290.,  310.,  330.,  350.,
        370.,  390.,  410.,  430.,  450.,  470.,  490.,  510.,  530.,
        550.,  570.,  590.,  610.,  630.,  650.,  670.,  690.,  710.,
        730.,  750.,  770.,  790.,  810.,  830.,  850.,  870.,  890.,
        910.,  930.,  950.,  970.,  990., 1010., 1030., 1050., 1070.,
       1090., 1110., 1130., 1150., 1170., 1190., 1210., 1230., 1250.,
       1270., 1290., 1310., 1330., 1350., 1370., 1390., 1410., 1430.,
       1450., 1470., 1490., 1510., 1530., 1550., 1570., 1590., 1610.,
       1630., 1650., 1670., 1690., 1710., 1730., 1750., 1770., 1790.,
       1810., 1830., 1850., 1870., 1890., 1910., 1930., 1950., 1970.,
       1990., 2010., 2030., 2050., 2070., 2090., 2110., 2130., 2150.,
       2170., 2190., 2210., 2230., 2250., 2270., 2290., 2310., 2330.,
       2350., 2370., 2390., 2410., 2430., 2450., 2470., 2490., 2510.,
       2530., 2550., 2570., 2590., 2610., 2630., 2650., 2670., 2690.,
       2710., 2730., 2750., 2770., 2790., 2810., 2830., 2850., 2870.,
       2890., 2910., 2930., 2950., 2970., 2990.]

        ql_sdm = [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.]

        qv_sdm = [0.01498378, 0.01495135, 0.01491892, 0.01488649, 0.01485405,
        0.01482162, 0.01478919, 0.01475676, 0.01472432, 0.01469189,
        0.01465946, 0.01462703, 0.01459459, 0.01456216, 0.01452973,
        0.0144973 , 0.01446486, 0.01443243, 0.0144    , 0.01436757,
        0.01433514, 0.0143027 , 0.01427027, 0.01423784, 0.01420541,
        0.01417297, 0.01414054, 0.01410811, 0.01407568, 0.01404324,
        0.01401081, 0.01397838, 0.01394595, 0.01391351, 0.01388108,
        0.01384865, 0.01381622, 0.01375476, 0.01366429, 0.01357381,
        0.01348333, 0.01339286, 0.01330238, 0.0132119 , 0.01312143,
        0.01303095, 0.01294048, 0.01285   , 0.01275952, 0.01266905,
        0.01257857, 0.0124881 , 0.01239762, 0.01230714, 0.01221667,
        0.01212619, 0.01203571, 0.01194524, 0.01185476, 0.01176429,
        0.01167381, 0.01158333, 0.01149286, 0.01140238, 0.0113119 ,
        0.01122143, 0.01113095, 0.01104048, 0.01095   , 0.01085952,
        0.01076905, 0.01067857, 0.0105881 , 0.01049762, 0.01040714,
        0.01031667, 0.01022619, 0.01013571, 0.01004524, 0.00995476,
        0.00986429, 0.00977381, 0.00968333, 0.00959286, 0.00950238,
        0.0094119 , 0.00932143, 0.00923095, 0.00914048, 0.00905   ,
        0.00895952, 0.00886905, 0.00877857, 0.0086881 , 0.00859762,
        0.00850714, 0.00841667, 0.00832619, 0.00823571, 0.00814524,
        0.00805476, 0.00796429, 0.00787381, 0.00778333, 0.00769286,
        0.00760238, 0.0075119 , 0.00742143, 0.00733095, 0.00724048,
        0.00715   , 0.00705952, 0.00696905, 0.00687857, 0.0067881 ,
        0.00669762, 0.00660714, 0.00651667, 0.00642619, 0.00633571,
        0.00624524, 0.00615476, 0.00606429, 0.00597381, 0.00588333,
        0.00579286, 0.00570238, 0.0056119 , 0.00552143, 0.00543095,
        0.00534048, 0.00525   , 0.00515952, 0.00506905, 0.00497857,
        0.0048881 , 0.00479762, 0.00470714, 0.00461667, 0.00452619,
        0.00443571, 0.00434524, 0.00425476, 0.00416429, 0.00407381,
        0.00398333, 0.00389286, 0.00380238, 0.0037119 , 0.00362143]

        rhod_sdm = [1.14682856, 1.14493933, 1.14305196, 1.14116646, 1.13928281,
        1.13740102, 1.13552109, 1.13364302, 1.13176681, 1.12989245,
        1.12801995, 1.1261493 , 1.12428051, 1.12241358, 1.12054849,
        1.11868527, 1.11682389, 1.11496436, 1.11310669, 1.11125087,
        1.10939689, 1.10754477, 1.1056945 , 1.10384607, 1.10199949,
        1.10015476, 1.09831188, 1.09647084, 1.09463164, 1.0927943 ,
        1.09095879, 1.08912513, 1.08729331, 1.08546334, 1.0836352 ,
        1.08180891, 1.07998446, 1.07816196, 1.07634218, 1.07452521,
        1.07271106, 1.07089972, 1.06909119, 1.06728547, 1.06548254,
        1.0636824 , 1.06188506, 1.0600905 , 1.05829872, 1.05650972,
        1.05472349, 1.05294002, 1.05115932, 1.04938138, 1.04760619,
        1.04583375, 1.04406406, 1.0422971 , 1.04053289, 1.0387714 ,
        1.03701265, 1.03525661, 1.0335033 , 1.0317527 , 1.03000481,
        1.02825963, 1.02651714, 1.02477736, 1.02304027, 1.02130587,
        1.01957415, 1.01784511, 1.01611875, 1.01439506, 1.01267404,
        1.01095568, 1.00923998, 1.00752693, 1.00581654, 1.00410879,
        1.00240368, 1.00070121, 0.99900138, 0.99730417, 0.99560959,
        0.99391764, 0.99222829, 0.99054156, 0.98885744, 0.98717593,
        0.98549701, 0.9838207 , 0.98214697, 0.98047583, 0.97880728,
        0.9771413 , 0.9754779 , 0.97381708, 0.97215882, 0.97050312,
        0.96884999, 0.96719941, 0.96555138, 0.9639059 , 0.96226296,
        0.96062256, 0.9589847 , 0.95734937, 0.95571656, 0.95408628,
        0.95245852, 0.95083327, 0.94921054, 0.94759031, 0.94597259,
        0.94435737, 0.94274464, 0.9411344 , 0.93952666, 0.93792139,
        0.93631861, 0.9347183 , 0.93312046, 0.9315251 , 0.92993219,
        0.92834175, 0.92675376, 0.92516823, 0.92358515, 0.92200451,
        0.92042631, 0.91885055, 0.91727723, 0.91570633, 0.91413786,
        0.91257181, 0.91100818, 0.90944697, 0.90788816, 0.90633177,
        0.90477777, 0.90322618, 0.90167698, 0.90013017, 0.89858575,
        0.89704372, 0.89550407, 0.89396679, 0.89243189, 0.89089936]

        thetad_sdm = [299.93246324, 299.92810105, 299.9237387 , 299.9193762 ,
        299.91501353, 299.91065071, 299.90628773, 299.90192459,
        299.89756129, 299.89319783, 299.88883422, 299.88447044,
        299.88010651, 299.87574242, 299.87137816, 299.86701375,
        299.86264918, 299.85828446, 299.85391957, 299.84955452,
        299.84518932, 299.84082395, 299.83645843, 299.83209275,
        299.8277269 , 299.8233609 , 299.81899474, 299.81462843,
        299.81026195, 299.80589531, 299.80152851, 299.79716156,
        299.79279445, 299.78842717, 299.78405974, 299.77969215,
        299.7753244 , 299.82598628, 299.93166981, 300.03734251,
        300.14300438, 300.24865542, 300.35429564, 300.45992502,
        300.56554357, 300.67115128, 300.77674816, 300.8823342 ,
        300.98790939, 301.09347375, 301.19902726, 301.30456992,
        301.41010174, 301.51562271, 301.62113282, 301.72663208,
        301.83212049, 301.93759804, 302.04306474, 302.14852057,
        302.25396554, 302.35939964, 302.46482289, 302.57023526,
        302.67563676, 302.7810274 , 302.88640716, 302.99177605,
        303.09713406, 303.20248119, 303.30781744, 303.41314281,
        303.5184573 , 303.6237609 , 303.72905362, 303.83433545,
        303.93960638, 304.04486643, 304.15011558, 304.25535383,
        304.36058119, 304.46579764, 304.5710032 , 304.67619785,
        304.7813816 , 304.88655444, 304.99171638, 305.0968674 ,
        305.20200751, 305.30713671, 305.41225499, 305.51736235,
        305.6224588 , 305.72754432, 305.83261892, 305.9376826 ,
        306.04273535, 306.14777717, 306.25280806, 306.35782802,
        306.46283705, 306.56783514, 306.6728223 , 306.77779851,
        306.88276379, 306.98771812, 307.09266151, 307.19759395,
        307.30251544, 307.40742599, 307.51232558, 307.61721422,
        307.7220919 , 307.82695863, 307.93181439, 308.0366592 ,
        308.14149305, 308.24631593, 308.35112784, 308.45592879,
        308.56071876, 308.66549777, 308.7702658 , 308.87502286,
        308.97976894, 309.08450404, 309.18922816, 309.29394129,
        309.39864345, 309.50333462, 309.60801479, 309.71268398,
        309.81734218, 309.92198939, 310.0266256 , 310.13125081,
        310.23586502, 310.34046824, 310.44506045, 310.54964165,
        310.65421185, 310.75877105, 310.86331923, 310.9678564 ,
        311.07238256, 311.1768977 , 311.28140183, 311.38589493,
        311.49037702, 311.59484808]

        T_sdm = [298.39269535, 298.19003911, 297.98738981, 297.78474744,
        297.58211199, 297.37948348, 297.17686189, 296.97424724,
        296.77163951, 296.56903872, 296.36644485, 296.16385792,
        295.96127791, 295.75870484, 295.55613869, 295.35357948,
        295.1510272 , 294.94848185, 294.74594343, 294.54341194,
        294.34088738, 294.13836976, 293.93585907, 293.7333553 ,
        293.53085848, 293.32836858, 293.12588562, 292.92340959,
        292.72094049, 292.51847833, 292.3160231 , 292.1135748 ,
        291.91113344, 291.70869901, 291.50627151, 291.30385095,
        291.10143732, 290.97379335, 290.9208525 , 290.86782894,
        290.8147227 , 290.76153383, 290.70826233, 290.65490826,
        290.60147164, 290.54795249, 290.49435085, 290.44066676,
        290.38690024, 290.33305132, 290.27912003, 290.22510641,
        290.17101049, 290.11683229, 290.06257185, 290.0082292 ,
        289.95380436, 289.89929738, 289.84470828, 289.79003709,
        289.73528384, 289.68044856, 289.62553128, 289.57053204,
        289.51545087, 289.46028779, 289.40504283, 289.34971604,
        289.29430743, 289.23881704, 289.18324489, 289.12759103,
        289.07185547, 289.01603826, 288.96013941, 288.90415897,
        288.84809696, 288.79195341, 288.73572836, 288.67942182,
        288.62303385, 288.56656445, 288.51001367, 288.45338153,
        288.39666807, 288.33987332, 288.2829973 , 288.22604005,
        288.1690016 , 288.11188197, 288.0546812 , 287.99739931,
        287.94003635, 287.88259233, 287.82506729, 287.76746127,
        287.70977427, 287.65200635, 287.59415753, 287.53622784,
        287.47821731, 287.42012597, 287.36195384, 287.30370097,
        287.24536738, 287.1869531 , 287.12845816, 287.06988259,
        287.01122642, 286.95248968, 286.89367241, 286.83477462,
        286.77579635, 286.71673764, 286.65759851, 286.59837898,
        286.5390791 , 286.47969889, 286.42023838, 286.3606976 ,
        286.30107658, 286.24137535, 286.18159394, 286.12173238,
        286.06179071, 286.00176894, 285.94166711, 285.88148525,
        285.82122339, 285.76088156, 285.70045979, 285.6399581 ,
        285.57937654, 285.51871512, 285.45797388, 285.39715285,
        285.33625206, 285.27527153, 285.2142113 , 285.1530714 ,
        285.09185185, 285.03055268, 284.96917394, 284.90771563,
        284.84617781, 284.78456048, 284.72286369, 284.66108746,
        284.59923183, 284.53729682]

        P_sdm = [100580.34507521, 100341.34612663, 100102.76133281,  99864.59023806,
        99626.83238692,  99389.48732414,  99152.55459473,  98916.03374389,
        98679.92431707,  98444.22585994,  98208.9379184 ,  97974.06003856,
        97739.59176678,  97505.53264964,  97271.88223392,  97038.64006667,
        96805.80569513,  96573.37866679,  96341.35852935,  96109.74483075,
        95878.53711915,  95647.73494294,  95417.33785072,  95187.34539134,
        94957.75711386,  94728.57256758,  94499.79130201,  94271.41286689,
        94043.43681221,  93815.86268815,  93588.69004514,  93361.91843384,
        93135.54740511,  92909.57651006,  92684.00530002,  92458.83332654,
        92234.06014142,  92029.14050023,  91844.01674148,  91659.21305234,
        91474.72894119,  91290.56391712,  91106.71748997,  90923.1891703 ,
        90739.97846941,  90557.08489931,  90374.50797275,  90192.24720322,
        90010.30210492,  89828.67219277,  89647.35698242,  89466.35599025,
        89285.66873335,  89105.29472953,  88925.23349732,  88745.48455597,
        88566.04742544,  88386.92162642,  88208.10668029,  88029.60210916,
        87851.40743585,  87673.52218389,  87495.9458775 ,  87318.67804164,
        87141.71820195,  86965.0658848 ,  86788.72061723,  86612.68192701,
        86436.94934262,  86261.52239321,  86086.40060865,  85911.58351951,
        85737.07065705,  85562.86155323,  85388.9557407 ,  85215.35275282,
        85042.05212361,  84869.05338783,  84696.35608088,  84523.95973888,
        84351.86389865,  84180.06809765,  84008.57187408,  83837.37476679,
        83666.47631532,  83495.87605991,  83325.57354146,  83155.56830156,
        82985.85988249,  82816.44782719,  82647.33167928,  82478.51098308,
        82309.98528354,  82141.75412634,  81973.81705778,  81806.17362487,
        81638.82337528,  81471.76585733,  81305.00062004,  81138.52721308,
        80972.34518678,  80806.45409216,  80640.85348087,  80475.54290526,
        80310.52191831,  80145.79007368,  79981.3469257 ,  79817.19202932,
        79653.32494018,  79489.74521458,  79326.45240946,  79163.44608241,
        79000.72579169,  78838.29109621,  78676.14155553,  78514.27672984,
        78352.69618001,  78191.39946755,  78030.38615461,  77869.65580398,
        77709.20797911,  77549.0422441 ,  77389.15816367,  77229.55530319,
        77070.23322869,  76911.19150682,  76752.42970487,  76593.94739078,
        76435.74413311,  76277.81950108,  76120.17306452,  75962.80439391,
        75805.71306035,  75648.89863559,  75492.36069199,  75336.09880256,
        75180.11254093,  75024.40148135,  74868.9651987 ,  74713.80326851,
        74558.9152669 ,  74404.30077063,  74249.95935708,  74095.89060426,
        73942.09409079,  73788.56939592,  73635.31609951,  73482.33378204,
        73329.62202462,  73177.18040894]


    elseif case=="wet_coarse"
            # Reference data from PySDM
        z_sdm = [  50.,  150.,  250.,  350.,  450.,  550.,  650.,  750.,  850.,
        950., 1050., 1150., 1250., 1350., 1450., 1550., 1650., 1750.,
        1850., 1950., 2050., 2150., 2250., 2350., 2450., 2550., 2650.,
        2750., 2850., 2950.]

        ql_sdm = [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.]

        qv_sdm = [0.01491892, 0.01475676, 0.01459459, 0.01443243, 0.01427027,
        0.01410811, 0.01394595, 0.01375476, 0.01330238, 0.01285   ,
        0.01239762, 0.01194524, 0.01149286, 0.01104048, 0.0105881 ,
        0.01013571, 0.00968333, 0.00923095, 0.00877857, 0.00832619,
        0.00787381, 0.00742143, 0.00696905, 0.00651667, 0.00606429,
        0.0056119 , 0.00515952, 0.00470714, 0.00425476, 0.00380238]

        rhod_sdm = [1.14305196, 1.13364302, 1.12428051, 1.11496436, 1.1056945 ,
        1.09647084, 1.08729331, 1.07816201, 1.06909122, 1.06009053,
        1.05115935, 1.04229713, 1.03350333, 1.02477739, 1.01611878,
        1.00752696, 0.99900141, 0.99054159, 0.982147  , 0.97381711,
        0.96555141, 0.9573494 , 0.94921057, 0.94113443, 0.93312049,
        0.92516826, 0.91727725, 0.909447  , 0.90167701, 0.89396682]

        thetad_sdm = [299.9237387 , 299.90192459, 299.88010651, 299.85828446,
        299.83645843, 299.81462843, 299.79279445, 299.82598628,
        300.35429564, 300.8823342 , 301.41010174, 301.93759804,
        302.46482289, 302.99177605, 303.5184573 , 304.04486643,
        304.5710032 , 305.0968674 , 305.6224588 , 306.14777717,
        306.6728223 , 307.19759395, 307.7220919 , 308.24631593,
        308.7702658 , 309.29394129, 309.81734218, 310.34046824,
        310.86331923, 311.38589493]

        T_sdm = [297.98738981, 296.97424724, 295.96127791, 294.94848185,
        293.93585907, 292.92340959, 291.91113344, 290.97379845,
        290.70826576, 290.44067019, 290.17101393, 289.89930083,
        289.62553474, 289.3497195 , 289.07185895, 288.79195689,
        288.51001716, 288.22604355, 287.94003986, 287.65200987,
        287.36195737, 287.06988612, 286.7757999 , 286.47970244,
        286.1815975 , 285.88148882, 285.57938011, 285.27527511,
        284.96917753, 284.66109106]

        P_sdm = [100102.76133281,  98916.03374389,  97739.59176678,  96573.37866679,
        95417.33785072,  94271.41286689,  93135.54740511,  92029.14614963,
        91106.72124606,  90192.2509342 ,  89285.67243933,  88386.92530754,
        87495.94953388,  86612.68555877,  85737.0742643 ,  84869.0569707 ,
        84008.57543269,  83155.57183604,  82309.988794  ,  81471.76934389,
        80640.85694365,  79817.19546843,  79000.72920727,  78191.4028597 ,
        77389.16153251,  76593.95073643,  75805.71638293,  75024.40478097,
        74249.96263386,  73482.3370361 ]

    elseif case=="dry_coarse"
        # Reference data from PySDM
        z_sdm = [  50.,  150.,  250.,  350.,  450.,  550.,  650.,  750.,  850.,
        950., 1050., 1150., 1250., 1350., 1450., 1550., 1650., 1750.,
        1850., 1950., 2050., 2150., 2250., 2350., 2450., 2550., 2650.,
        2750., 2850., 2950.]

        ql_sdm = [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.]

        qv_sdm = [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.]

        rhod_sdm = [1.1706593 , 1.16109334, 1.15157447, 1.14210259, 1.13267763,
        1.12329951, 1.11396816, 1.10468366, 1.09546078, 1.08630939,
        1.0772289 , 1.06821874, 1.05927836, 1.05040718, 1.04160466,
        1.03287025, 1.02420341, 1.01560358, 1.00707025, 0.99860288,
        0.99020095, 0.98186394, 0.97359133, 0.96538261, 0.95723729,
        0.94915484, 0.9411348 , 0.93317665, 0.92527991, 0.9174441 ]

        thetad_sdm = [297.9       , 297.9       , 297.9       , 297.9       ,
        297.9       , 297.9       , 297.9       , 297.95857143,
        298.54428571, 299.13      , 299.71571429, 300.30142857,
        300.88714286, 301.47285714, 302.05857143, 302.64428571,
        303.23      , 303.81571429, 304.40142857, 304.98714286,
        305.57285714, 306.15857143, 306.74428571, 307.33      ,
        307.91571429, 308.50142857, 309.08714286, 309.67285714,
        310.25857143, 310.84428571]

        T_sdm = [298.00613302, 297.03034695, 296.05456089, 295.07877482,
        294.10298875, 293.12720268, 292.15141661, 291.25578532,
        291.08036742, 290.90289845, 290.72337913, 290.54181187,
        290.35819905, 290.17254308, 289.98484633, 289.79511119,
        289.60334002, 289.40953518, 289.21369903, 289.01583391,
        288.81594217, 288.61402614, 288.41008814, 288.20413049,
        287.9961555 , 287.78616548, 287.57416273, 287.36014953,
        287.14412817, 286.92610092]

        P_sdm = [100124.81122361,  98981.48097221,  97847.50862761,  96722.84806231,
        95607.45322506,  94501.27814093,  93404.27691148,  92341.83102036,
        91515.72749575,  90695.88226719,  89882.25147442,  89074.79343103,
        88273.46673215,  87478.23025216,  86689.04314257,  85905.86482972,
        85128.65501271,  84357.37366115,  83591.9810131 ,  82832.43757294,
        82078.70410926,  81330.74165281,  80588.51149443,  79851.97518305,
        79121.09452364,  78395.83157525,  77676.14864902,  76962.00830621,
        76253.3733563 ,  75550.20685504]
    end

#! format: on

    qv_sdm = qv_sdm ./ (1 .+ qv_sdm)
    rho_sdm = rhod_sdm .* (1 .+ qv_sdm)

    return (; z_sdm, qv_sdm, rho_sdm, thetad_sdm, T_sdm, P_sdm, ql_sdm)
end
